﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2014 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Problems.DataAnalysis.Symbolic {
  /// <summary>
  /// An arc that can have a weight, a label, and can old additional information in the Data object
  /// </summary>
  [StorableClass]
  public class Arc : Item, IArc {
    [Storable]
    public IVertex Source { get; set; }

    [Storable]
    public IVertex Target { get; set; }

    [Storable]
    public string Label { get; set; }

    [Storable]
    public double Weight { get; set; }

    [Storable]
    public object Data { get; set; }

    [StorableConstructor]
    public Arc(bool deserializing) : base(deserializing) { }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new Arc(this, cloner);
    }
    public Arc() { }

    public Arc(IVertex source, IVertex target) {
      Source = source;
      Target = target;
    }

    protected Arc(Arc original, Cloner cloner)
      : base(original, cloner) {
      Source = original.Source;
      Target = original.Target;
      Label = original.Label;
      Weight = original.Weight;
      Data = original.Data;
    }
  }
}
